run_hooks

Function run_hooks 

pub fn run_hooks(
    repo_root: &Path,
    hook_name: &str,
    env: &HashMap<String, String>,
) -> Result<Vec<HookResult>, HookError>
Run all hooks of a given type from a directory (for extensibility).

If multiple scripts match (e.g., pre-commit.d/ directory), all are run in sorted order, and any failure aborts the chain.