pub fn compose_chain(
patches: &[Patch],
author: &str,
message: &str,
) -> Result<ComposeResult, ComposeError>Expand description
Compose a sequence of patches into a single equivalent patch.
Patches must form a linear chain: each patch’s first parent is the previous patch.
Unlike compose, this does not require strict ancestry verification between
intermediate composed results and the next patch, since the intermediate
composed patch has a new ID.