detect_conflicts

Function detect_conflicts 

pub fn detect_conflicts(
    patches_a: &[Patch],
    patches_b: &[Patch],
) -> Vec<Conflict>
Detect all conflicts between two patch sets without performing a full merge.

This is useful for showing a preview of what would conflict before actually committing to a merge.