pub enum RepoError {
}Expand description
Repository errors.
Variants
NotARepository(PathBuf)
The given path is not a Suture repository (no .suture/ directory).
AlreadyExists(PathBuf)
A Suture repository already exists at the given path.
Cas(CasError)
An error occurred in the Content Addressable Storage.
Dag(DagError)
An error occurred in the Patch DAG.
Meta(MetaError)
An error occurred in the metadata store.
Io(Error)
An I/O error occurred.
Apply(ApplyError)
An error occurred during patch application.
Patch(String)
A patch-related error occurred.
NothingToCommit
No changes are staged for commit.
MergeInProgress
A merge is in progress with unresolved conflicts.
DirtyWorkingTree(usize)
Uncommitted staged changes would be overwritten by this operation.
BranchNotFound(String)
The specified branch was not found.
Common(CommonError)
An error from the suture-common crate.
Custom(String)
A generic custom error.
Unsupported(String)
The requested operation is not supported.